@@ -39,6 +39,19 @@ FetLoadFileDialog::~FetLoadFileDialog()
 }
 
 
+void FetLoadFileDialog::on_sourceComboBox_activated(const QString &arg1)
+{
+  if (arg1 == "Remote Webcams File (HTTP Protocol)")
+  {
+    ui->urlLineEdit->setEnabled(true);
+  }
+  else
+  {
+    ui->urlLineEdit->setEnabled(false);
+  }
+}
+
+
 void FetLoadFileDialog::on_buttonBox_accepted()
 {
   // Need to do better than accessing raw index values here!
@@ -48,7 +61,7 @@ void FetLoadFileDialog::on_buttonBox_accepted()
     xmlFileReply = xmlFileRetriever.get(
       QNetworkRequest(
         QUrl(
-          "http://jpietrzak8.github.io/Fettuccine/fettuccine.xml")));
+          ui->urlLineEdit->text())));
 
     connect(
       xmlFileReply,
